==> xfce4-power-manager-0.8.1.1.tar.bz2: xfce4-power-manager-0.8.1.1/src/xfpm-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include <xfpm-enum-types.h>
#include "xfpm-enum-glib.h"


/* enumerations from "./xfpm-enum-glib.h" */
GType
xfpm_shutdown_request_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ XFPM_DO_NOTHING, "XFPM_DO_NOTHING", "do-nothing" },
	{ XFPM_DO_SUSPEND, "XFPM_DO_SUSPEND", "do-suspend" },
	{ XFPM_DO_HIBERNATE, "XFPM_DO_HIBERNATE", "do-hibernate" },
	{ XFPM_ASK, "XFPM_ASK", "ask" },
	{ XFPM_DO_SHUTDOWN, "XFPM_DO_SHUTDOWN", "do-shutdown" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmShutdownRequest", values);
  }
	return type;
}
GType
xfpm_lid_trigger_action_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ LID_TRIGGER_NOTHING, "LID_TRIGGER_NOTHING", "nothing" },
	{ LID_TRIGGER_SUSPEND, "LID_TRIGGER_SUSPEND", "suspend" },
	{ LID_TRIGGER_HIBERNATE, "LID_TRIGGER_HIBERNATE", "hibernate" },
	{ LID_TRIGGER_LOCK_SCREEN, "LID_TRIGGER_LOCK_SCREEN", "lock-screen" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmLidTriggerAction", values);
  }
	return type;
}
GType
xfpm_battery_state_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ BATTERY_FULLY_CHARGED, "BATTERY_FULLY_CHARGED", "fully-charged" },
	{ BATTERY_NOT_FULLY_CHARGED, "BATTERY_NOT_FULLY_CHARGED", "not-fully-charged" },
	{ BATTERY_IS_CHARGING, "BATTERY_IS_CHARGING", "is-charging" },
	{ BATTERY_IS_DISCHARGING, "BATTERY_IS_DISCHARGING", "is-discharging" },
	{ BATTERY_CHARGE_LOW, "BATTERY_CHARGE_LOW", "charge-low" },
	{ BATTERY_CHARGE_CRITICAL, "BATTERY_CHARGE_CRITICAL", "charge-critical" },
	{ BATTERY_NOT_PRESENT, "BATTERY_NOT_PRESENT", "not-present" },
	{ BATTERY_STATE_UNKNOWN, "BATTERY_STATE_UNKNOWN", "state-unknown" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmBatteryState", values);
  }
	return type;
}
GType
xfpm_button_key_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ BUTTON_POWER_OFF, "BUTTON_POWER_OFF", "power-off" },
	{ BUTTON_HIBERNATE, "BUTTON_HIBERNATE", "hibernate" },
	{ BUTTON_SLEEP, "BUTTON_SLEEP", "sleep" },
	{ BUTTON_MON_BRIGHTNESS_UP, "BUTTON_MON_BRIGHTNESS_UP", "mon-brightness-up" },
	{ BUTTON_MON_BRIGHTNESS_DOWN, "BUTTON_MON_BRIGHTNESS_DOWN", "mon-brightness-down" },
	{ BUTTON_LID_CLOSED, "BUTTON_LID_CLOSED", "lid-closed" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmButtonKey", values);
  }
	return type;
}
GType
xfpm_show_icon_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ SHOW_ICON_ALWAYS, "SHOW_ICON_ALWAYS", "always" },
	{ SHOW_ICON_WHEN_BATTERY_PRESENT, "SHOW_ICON_WHEN_BATTERY_PRESENT", "when-battery-present" },
	{ SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING, "SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING", "when-battery-charging-discharging" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmShowIcon", values);
  }
	return type;
}

/* Generated data ends here */

==> xfce4-power-manager-0.8.3.1.tar.bz2: xfce4-power-manager-0.8.3.1/src/xfpm-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include <xfpm-enum-types.h>
#include "xfpm-enum-glib.h"


/* enumerations from "./xfpm-enum-glib.h" */
GType
xfpm_shutdown_request_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ XFPM_DO_NOTHING, "XFPM_DO_NOTHING", "do-nothing" },
	{ XFPM_DO_SUSPEND, "XFPM_DO_SUSPEND", "do-suspend" },
	{ XFPM_DO_HIBERNATE, "XFPM_DO_HIBERNATE", "do-hibernate" },
	{ XFPM_ASK, "XFPM_ASK", "ask" },
	{ XFPM_DO_SHUTDOWN, "XFPM_DO_SHUTDOWN", "do-shutdown" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmShutdownRequest", values);
  }
	return type;
}
GType
xfpm_lid_trigger_action_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ LID_TRIGGER_NOTHING, "LID_TRIGGER_NOTHING", "nothing" },
	{ LID_TRIGGER_SUSPEND, "LID_TRIGGER_SUSPEND", "suspend" },
	{ LID_TRIGGER_HIBERNATE, "LID_TRIGGER_HIBERNATE", "hibernate" },
	{ LID_TRIGGER_LOCK_SCREEN, "LID_TRIGGER_LOCK_SCREEN", "lock-screen" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmLidTriggerAction", values);
  }
	return type;
}
GType
xfpm_battery_state_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ BATTERY_FULLY_CHARGED, "BATTERY_FULLY_CHARGED", "fully-charged" },
	{ BATTERY_NOT_FULLY_CHARGED, "BATTERY_NOT_FULLY_CHARGED", "not-fully-charged" },
	{ BATTERY_IS_CHARGING, "BATTERY_IS_CHARGING", "is-charging" },
	{ BATTERY_IS_DISCHARGING, "BATTERY_IS_DISCHARGING", "is-discharging" },
	{ BATTERY_CHARGE_LOW, "BATTERY_CHARGE_LOW", "charge-low" },
	{ BATTERY_CHARGE_CRITICAL, "BATTERY_CHARGE_CRITICAL", "charge-critical" },
	{ BATTERY_NOT_PRESENT, "BATTERY_NOT_PRESENT", "not-present" },
	{ BATTERY_STATE_UNKNOWN, "BATTERY_STATE_UNKNOWN", "state-unknown" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmBatteryState", values);
  }
	return type;
}
GType
xfpm_button_key_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ BUTTON_POWER_OFF, "BUTTON_POWER_OFF", "power-off" },
	{ BUTTON_HIBERNATE, "BUTTON_HIBERNATE", "hibernate" },
	{ BUTTON_SLEEP, "BUTTON_SLEEP", "sleep" },
	{ BUTTON_MON_BRIGHTNESS_UP, "BUTTON_MON_BRIGHTNESS_UP", "mon-brightness-up" },
	{ BUTTON_MON_BRIGHTNESS_DOWN, "BUTTON_MON_BRIGHTNESS_DOWN", "mon-brightness-down" },
	{ BUTTON_LID_CLOSED, "BUTTON_LID_CLOSED", "lid-closed" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmButtonKey", values);
  }
	return type;
}
GType
xfpm_show_icon_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ SHOW_ICON_ALWAYS, "SHOW_ICON_ALWAYS", "show-icon-always" },
	{ SHOW_ICON_WHEN_BATTERY_PRESENT, "SHOW_ICON_WHEN_BATTERY_PRESENT", "show-icon-when-battery-present" },
	{ SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING, "SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING", "show-icon-when-battery-charging-discharging" },
	{ NEVER_SHOW_ICON, "NEVER_SHOW_ICON", "never-show-icon" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("XfpmShowIcon", values);
  }
	return type;
}

/* Generated data ends here */
